# NoJS

## The next generation of web development

### Get started

#### Pip Install

pip install nopm

### Use it

Create a folder called public containing all of your server assets. Then you can create a file called nojs.config.json with configurable settings. You can then run it with python -m nojs

Due to reasons, the nojs/python -m nojs and nopm/python -m nopm methods are not currently working. They can be accessed by doing:

python
import nojs, nopm # Load the nojs modules
nopm.i("package") # Install a package
nopm.r("package") # Uninstall a package
nojs.run() # Start the server